==> PyNFe-1.0.22.tar.gz: PyNFe-1.0.22/pynfe/nfce/manual_600/consrecinfce.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.nfe.manual_600 import conssitnfe as conssitnfe_600
from pynfe.nfe.manual_600.consrecinfe import ProtNFe, ProcNFe
from pynfe.xml_sped.base import ABERTURA
from .cancnfce import RetCancNFe
from .nfce_p import NFCe


class ProcNFCe(ProcNFe):
    def __init__(self):
        super(ProcNFCe, self).__init__()
        self.NFe = NFCe()

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.NFe.xml.replace(ABERTURA, '')
        if self.protNFe.infProt.Id.valor or self.protNFe.infProt.cStat.valor:
            xml += self.protNFe.xml.replace(ABERTURA, '')
        if self.cancNfe.xml and self.cancNfe.infCanc.cStat.valor:
            xml += self.cancNfe.xml.replace(ABERTURA, '')
        xml += '</nfeProc>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.NFe.xml = arquivo
            self.protNFe.xml = arquivo
            self.cancNfe.xml = arquivo


class RetConsSitNFe(conssitnfe_600.RetConsSitNFe):
    def __init__(self):
        super(RetConsSitNFe, self).__init__()

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        xml += self.chNFe.xml
        if self.protNFe is not None:
            xml += self.protNFe.xml
        if self.retCancNFe is not None:
            xml += self.retCancNFe.raw_xml()
        for p in self.procEventoNFe:
            xml += p.xml
        xml += '</retConsSitNFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.dhRecbto.xml = arquivo
            self.chNFe.xml = arquivo
            if self._le_noh('//retConsSitNFe/protNFe'):
                self.protNFe = ProtNFe()
                self.protNFe.xml = arquivo
            if self._le_noh('//retConsSitNFe/retCancNFe'):
                self.retCancNFe = RetCancNFe()
                self.retCancNFe.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> PyNFe-5.0.10.tar.gz: PyNFe-5.0.10/pynfe/nfce/manual_600/consrecinfce.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.nfe.manual_600 import conssitnfe as conssitnfe_600
from pynfe.nfe.manual_600.consrecinfe import ProtNFe, ProcNFe
from pynfe.xml_sped.base import ABERTURA
from .cancnfce import RetCancNFe
from .nfce_p import NFCe


class ProcNFCe(ProcNFe):
    def __init__(self):
        super(ProcNFCe, self).__init__()
        self.NFe = NFCe()

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.NFe.xml.replace(ABERTURA, '')
        xml += self.protNFe.xml.replace(ABERTURA, '')
        xml += '</nfeProc>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.NFe.xml = arquivo
            self.protNFe.xml = arquivo


class RetConsSitNFe(conssitnfe_600.RetConsSitNFe):
    def __init__(self):
        super(RetConsSitNFe, self).__init__()

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        xml += self.chNFe.xml
        if self.protNFe is not None:
            xml += self.protNFe.xml
        if self.retCancNFe is not None:
            xml += self.retCancNFe.raw_xml
        for p in self.procEventoNFe:
            xml += p.xml
        xml += '</retConsSitNFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.dhRecbto.xml = arquivo
            self.chNFe.xml = arquivo
            if self._le_noh('//retConsSitNFe/protNFe'):
                self.protNFe = ProtNFe()
                self.protNFe.xml = arquivo
            if self._le_noh('//retConsSitNFe/retCancNFe'):
                self.retCancNFe = RetCancNFe()
                self.retCancNFe.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
